estimate_pi: Simple Pi estimation

Description Usage Arguments Value Functions Examples

View source: R/pi.R

Description

Simple Pi estimation

Usage

1
estimate_pi(B = 5000, seed = 10)

Arguments

B

A numeric (integer) used to denote the number of points simulated

seed

A numeric used to control the seed of the random number generator used by this function.

Value

A list of class pi with the attributes points and estimation

Functions

Examples

1
estimate_pi(500, 6)

rsefraou/ptds2019hw4g1 documentation built on Nov. 20, 2019, 9:48 a.m.